# ys-dl

Command-line program to download images from Genshin Impact Community.

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/XavierJiezou/ys-dl/Release)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/c2f85c8d6b8a4892b40059703f087eab)](https://www.codacy.com/gh/XavierJiezou/ys-dl/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=XavierJiezou/ys-dl&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/XavierJiezou/ys-dl/branch/main/graph/badge.svg?token=AFQB7E7JID)](https://codecov.io/gh/XavierJiezou/ys-dl)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ys-dl)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ys-dl)
![PyPI](https://img.shields.io/pypi/v/ys-dl)
[![GitHub stars](https://img.shields.io/github/stars/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/network)
[![GitHub issues](https://img.shields.io/github/issues/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/issues)
[![GitHub license](https://img.shields.io/github/license/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/blob/main/LICENSE)

## Demo

## Install

```bash
pip install ys-dl
```

## Usage

`$ ys-dl`

## Changelog

See [CHANGELOG.md](CHANGELOG.md)

## License

[MIT License](License)

## References

- [Python dependency management and packaging made easy.](https://github.com/python-poetry/poetry)